@@ -1,5 +1,6 @@
 
-/*  A Bison parser, made from field_y.y with Bison version GNU Bison version 1.24
+/*  A Bison parser, made from field_y.y
+ by  GNU Bison version 1.25
   */
 
 #define YYBISON 1  /* Identify Bison output.  */
@@ -121,23 +122,6 @@ typedef union {
    char cval;
    DateDescription date;
    } YYSTYPE;
-
-#ifndef YYLTYPE
-typedef
-  struct fieldltype
-    {
-      int timestamp;
-      int first_line;
-      int first_column;
-      int last_line;
-      int last_column;
-      char *text;
-   }
-  fieldltype;
-
-#define YYLTYPE fieldltype
-#endif
-
 #include <stdio.h>
 
 #ifndef __cplusplus
@@ -220,6 +204,10 @@ static const short fieldrline[] = { 0,
    396,   397,   398,   400,   411,   422,   438,   452,   453,   454,
    457,   458,   461,   462,   465,   466
 };
+#endif
+
+
+#if YYDEBUG != 0 || defined (YYERROR_VERBOSE)
 
 static const char * const fieldtname[] = {   "$","error","$undefined.","WORD","REGEXP",
 "FIELD","END","LAYOUT","STEMMING","ISOUNDEX","IPHONIX","NUMERIC","ITEXT","LOCAL",
@@ -227,7 +215,7 @@ static const char * const fieldtname[] = {   "$","error","$undefined.","WORD","R
 "YEAR","STRING","DESCRIPTION","docspec","parseformat","format","record","layout",
 "end","layoutspecs","layoutspec","speclist","spec","@1","@2","options","option",
 "regexp","indexspecs","indexspec","indextype","dicts","date_spec","date","monthspec",
-"descr","fieldlist",""
+"descr","fieldlist", NULL
 };
 #endif
 
@@ -458,16 +446,16 @@ int fieldparse (void);
 #endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
-#define __field_memcpy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
+#define __field_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
 #ifndef __cplusplus
 
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__field_memcpy (from, to, count)
-     char *from;
+__field_memcpy (to, from, count)
      char *to;
+     char *from;
      int count;
 {
   register char *f = from;
@@ -483,7 +471,7 @@ __field_memcpy (from, to, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__field_memcpy (char *from, char *to, int count)
+__field_memcpy (char *to, char *from, int count)
 {
   register char *f = from;
   register char *t = to;
@@ -505,14 +493,20 @@ __field_memcpy (char *from, char *to, int count)
    to the proper pointer type.  */
 
 #ifdef YYPARSE_PARAM
-#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
-#else
-#define YYPARSE_PARAM
+#ifdef __cplusplus
+#define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
 #define YYPARSE_PARAM_DECL
-#endif
+#else /* not __cplusplus */
+#define YYPARSE_PARAM_ARG YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
+#endif /* not __cplusplus */
+#else /* not YYPARSE_PARAM */
+#define YYPARSE_PARAM_ARG
+#define YYPARSE_PARAM_DECL
+#endif /* not YYPARSE_PARAM */
 
 int
-fieldparse(YYPARSE_PARAM)
+fieldparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
 {
   register int fieldstate;
@@ -629,12 +623,12 @@ fieldnewstate:
       if (fieldstacksize > YYMAXDEPTH)
 	fieldstacksize = YYMAXDEPTH;
       fieldss = (short *) alloca (fieldstacksize * sizeof (*fieldssp));
-      __field_memcpy ((char *)fieldss1, (char *)fieldss, size * sizeof (*fieldssp));
+      __field_memcpy ((char *)fieldss, (char *)fieldss1, size * sizeof (*fieldssp));
       fieldvs = (YYSTYPE *) alloca (fieldstacksize * sizeof (*fieldvsp));
-      __field_memcpy ((char *)fieldvs1, (char *)fieldvs, size * sizeof (*fieldvsp));
+      __field_memcpy ((char *)fieldvs, (char *)fieldvs1, size * sizeof (*fieldvsp));
 #ifdef YYLSP_NEEDED
       fieldls = (YYLTYPE *) alloca (fieldstacksize * sizeof (*fieldlsp));
-      __field_memcpy ((char *)fieldls1, (char *)fieldls, size * sizeof (*fieldlsp));
+      __field_memcpy ((char *)fieldls, (char *)fieldls1, size * sizeof (*fieldlsp));
 #endif
 #endif /* no fieldoverflow */
 
