@@ -1,5 +1,6 @@
 
-/*  A Bison parser, made from query_y.y with Bison version GNU Bison version 1.24
+/*  A Bison parser, made from query_y.y
+ by  GNU Bison version 1.25
   */
 
 #define YYBISON 1  /* Identify Bison output.  */
@@ -67,23 +68,6 @@ typedef union {
    int  ival;
    char *sval;
    } YYSTYPE;
-
-#ifndef YYLTYPE
-typedef
-  struct queryltype
-    {
-      int timestamp;
-      int first_line;
-      int first_column;
-      int last_line;
-      int last_column;
-      char *text;
-   }
-  queryltype;
-
-#define YYLTYPE queryltype
-#endif
-
 #include <stdio.h>
 
 #ifndef __cplusplus
@@ -162,12 +146,16 @@ static const short queryrline[] = { 0,
    193,   223,   224,   225,   227,   228,   230,   234,   245,   249,
    256,   260,   267,   274,   283,   294,   299,   304,   318,   319
 };
+#endif
+
+
+#if YYDEBUG != 0 || defined (YYERROR_VERBOSE)
 
 static const char * const querytname[] = {   "$","error","$undefined.","WORD","PHONIX",
 "SOUNDEX","ASSIGN","FLOAT","OR","AND","NOT","PROX_ORDERED","PROX_UNORDERED",
 "PROX_ATLEAST","'('","')'","'='","'<'","'>'","query","or","and","expression",
 "term","factor","unit","@1","@2","@3","relop","phonsound","s_expression","s_term",
-"s_factor","s_unit","a_unit","w_unit",""
+"s_factor","s_unit","a_unit","w_unit", NULL
 };
 #endif
 
@@ -394,16 +382,16 @@ int queryparse (void);
 #endif
 
 #if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
-#define __query_memcpy(FROM,TO,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
+#define __query_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
 #else				/* not GNU C or C++ */
 #ifndef __cplusplus
 
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__query_memcpy (from, to, count)
-     char *from;
+__query_memcpy (to, from, count)
      char *to;
+     char *from;
      int count;
 {
   register char *f = from;
@@ -419,7 +407,7 @@ __query_memcpy (from, to, count)
 /* This is the most reliable way to avoid incompatibilities
    in available built-in functions on various systems.  */
 static void
-__query_memcpy (char *from, char *to, int count)
+__query_memcpy (char *to, char *from, int count)
 {
   register char *f = from;
   register char *t = to;
@@ -441,14 +429,20 @@ __query_memcpy (char *from, char *to, int count)
    to the proper pointer type.  */
 
 #ifdef YYPARSE_PARAM
-#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
-#else
-#define YYPARSE_PARAM
+#ifdef __cplusplus
+#define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
 #define YYPARSE_PARAM_DECL
-#endif
+#else /* not __cplusplus */
+#define YYPARSE_PARAM_ARG YYPARSE_PARAM
+#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
+#endif /* not __cplusplus */
+#else /* not YYPARSE_PARAM */
+#define YYPARSE_PARAM_ARG
+#define YYPARSE_PARAM_DECL
+#endif /* not YYPARSE_PARAM */
 
 int
-queryparse(YYPARSE_PARAM)
+queryparse(YYPARSE_PARAM_ARG)
      YYPARSE_PARAM_DECL
 {
   register int querystate;
@@ -565,12 +559,12 @@ querynewstate:
       if (querystacksize > YYMAXDEPTH)
 	querystacksize = YYMAXDEPTH;
       queryss = (short *) alloca (querystacksize * sizeof (*queryssp));
-      __query_memcpy ((char *)queryss1, (char *)queryss, size * sizeof (*queryssp));
+      __query_memcpy ((char *)queryss, (char *)queryss1, size * sizeof (*queryssp));
       queryvs = (YYSTYPE *) alloca (querystacksize * sizeof (*queryvsp));
-      __query_memcpy ((char *)queryvs1, (char *)queryvs, size * sizeof (*queryvsp));
+      __query_memcpy ((char *)queryvs, (char *)queryvs1, size * sizeof (*queryvsp));
 #ifdef YYLSP_NEEDED
       queryls = (YYLTYPE *) alloca (querystacksize * sizeof (*querylsp));
-      __query_memcpy ((char *)queryls1, (char *)queryls, size * sizeof (*querylsp));
+      __query_memcpy ((char *)queryls, (char *)queryls1, size * sizeof (*querylsp));
 #endif
 #endif /* no queryoverflow */
 
