@@ -1,6 +1,6 @@
 /*                               -*- Mode: C -*- 
  * $Basename: waisserver.c $
- * $Revision: 1.9.1.13.1.3 $
+ * $Revision: 1.9.1.13.1.4 $
  * Author          : Harry Morris, morris@think.com
  * Created On      : 5.29.90
  * Last Modified By: Ulrich Pfeifer
@@ -14,10 +14,10 @@
  */
 
 /* $Format: "#define SERVER_DATE \"$Date$\""$ */
-#define SERVER_DATE "Mon, 05 May 1997 11:54:27 +0200"
+#define SERVER_DATE "Thu, 25 Feb 1999 09:46:46 +0100"
 
 #ifndef lint
-static char *PRCSid = "$Id: waisserver.c 1.9.1.13.1.3 Mon, 05 May 1997 11:54:27 +0200 pfeifer $";
+static char *PRCSid = "$Id: waisserver.c 1.9.1.13.1.4 Thu, 25 Feb 1999 09:46:46 +0100 goevert $";
 #endif
 
 #define INFO_DICT    "INFO.dct"
@@ -313,9 +313,6 @@ srcfiles(e)
 /*---------------------------------------------------------------------------*/
 
 #ifdef HAS_SYS_ERRLIST
-#ifdef EXTERN_SYS_ERRLIST
-extern char *sys_errlist[];
-#endif
 extern int      errno;
 extern int      sys_nerr;
 #endif
