@@ -1,62 +1,21 @@
-/* 
-  WIDE AREA INFORMATION SERVER SOFTWARE:
-   No guarantees or restrictions.  See the readme file for the full standard
-   disclaimer.
-
-   This is part of the shell user-interface tools for the WAIS software.
-   Do with it as you please.
-
-   jonathan@Think.COM
-*/
-
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
-
-/*
- * $Log: document.c,v $
- * Revision 2.0.1.3  1995/11/14 18:26:33  pfeifer
- * patch51:
- *
- * Revision 2.0.1.2  1995/09/15  09:53:11  pfeifer
- * patch7: Fixed CNIDR copyright line.
- *
- * Revision 2.0.1.1  1995/09/11  13:00:48  pfeifer
- * patch4:
- *
- * Revision 2.0  1995/09/08  08:04:33  pfeifer
- * Metaconfig baseline
- *
- * Revision 1.3  1995/01/10  16:51:38  pfeifer
- * Little fix for multiple submissions of the same query, which breaks xwasq.
- * Not the last!
- *
- * Revision 1.2  1994/08/05  07:29:53  pfeifer
- * Release beta 04
- *
- * Revision 1.1  93/06/23  20:02:04  warnock
- * Initial revision
- * 
- * Revision 1.1  1993/02/16  15:09:27  freewais
- * Initial revision
- *
- * Revision 1.10  92/05/07  14:50:27  jonathan
- * Fixed listing for sections starting at 0.
- * 
- * Revision 1.9  92/04/02  14:23:36  jonathan
- * fleshed out copy_cretdoc.
- * 
- * Revision 1.8  92/04/01  17:16:20  jonathan
- * Added some copying functions.
- * 
- * Revision 1.7  92/03/17  14:36:40  jonathan
- * Cleaned up for use with X interface as well.
- * 
- * Revision 1.6  92/03/08  09:13:13  jonathan
- * strip lf from headlines.
+/*                               -*- Mode: C -*- 
+ * $Basename: document.c $
+ * $Revision: 1.6.1.7.1.3 $
+ * Author          : jonathan@Think.COM
+ * Created On      : 92/03/08  09:13:13
+ * Last Modified By: Ulrich Pfeifer
+ * Last Modified On: Mon May  5 10:22:22 1997
+ * Language        : C
+ * Update Count    : 1
+ * Status          : Unknown, Use with caution!
  * 
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
  */
 
+
 #ifndef lint
-static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ui/RCS/document.c,v 2.0.1.3 1995/11/14 18:26:33 pfeifer Exp $";
+static char *PRCSid = "$Id: document.c 1.6.1.7.1.3 Mon, 05 May 1997 11:54:27 +0200 pfeifer $";
 #endif
 
 #include "wais.h"
