@@ -1,88 +1,23 @@
-/* 
-  WIDE AREA INFORMATION SERVER SOFTWARE:
-   No guarantees or restrictions.  See the readme file for the full standard
-   disclaimer.
-
-   This is part of the shell user-interface tools for the WAIS software.
-   Do with it as you please.
-
-   jonathan@Think.COM
-*/
-
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
-
-/*
- * $Log: source.c,v $
- * Revision 2.0.1.2  1995/09/15 09:53:54  pfeifer
- * patch7: Fixed CNIDR copyright line.
- *
- * Revision 2.0.1.1  1995/09/11  13:01:12  pfeifer
- * patch4: Changed TELL_USER to call getuser_name().
- *
- * Revision 2.0  1995/09/08  08:05:19  pfeifer
- * Metaconfig baseline
- *
- * Revision 1.7  1994/08/22  14:13:31  pfeifer
- * jp made the getenv code safer
- *
- * Revision 1.6  1994/08/15  16:17:05  pfeifer
- * fixed uncheckt usage of getenv("USER") in printf
- *
- * Revision 1.5  1994/08/05  07:30:16  pfeifer
- * Release beta 04
- *
- * Revision 1.4  93/07/02  19:27:26  warnock
- * fix call to getdomainname from mike@tab00.larc.nasa.gov
- * 
- * Revision 1.3  93/07/01  19:21:26  warnock
- * gethostname -> mygethostname
- * 
- * Revision 1.2  93/06/23  20:06:03  warnock
- * Removed FORWARDER_SERVER pointer to Francois
- * 
- * Revision 1.1  93/06/23  20:02:20  warnock
- * Initial revision
- * 
- * Revision 1.1  1993/02/16  15:09:27  freewais
- * Initial revision
- *
- * Revision 1.16  92/04/02  14:22:23  jonathan
- * Added sopysourceID.
- * 
- * Revision 1.15  92/04/01  17:18:39  jonathan
- * Added FORWARDER_SERVER stuff.
- * 
- * Revision 1.14  92/03/17  14:39:55  jonathan
- * Cleaned up.
- * 
- * Revision 1.13  92/03/06  14:50:53  jonathan
- * New and Improved source loading!
- * 
- * Revision 1.12  92/03/05  11:47:30  jonathan
- * Replaced directory routines with scandir's.
- * 
- * Revision 1.11  92/03/04  19:21:11  jonathan
- * Handle EOF on read of source.  This fixes looping when source description
- * is broken.
- * 
- * Revision 1.10  92/03/04  18:45:17  jonathan
- * Modified WriteSource to use WriteString for description.
- * 
- * Revision 1.9  92/03/01  13:53:30  jonathan
- * Added routines for X interface in effort to combine x/source.c and
- * ui/source.c
- * 
- * Revision 1.8  92/03/01  13:07:25  jonathan
- * Added check of s->thisSource to avoid errors when there are no sources.
+/*                               -*- Mode: C -*- 
+ * $Basename: source.c $
+ * $Revision: 1.7.1.5.1.4 $
+ * Author          : jonathan@Think.COM
+ * Created On      : 92/03/01  13:07:25
+ * Last Modified By: Ulrich Pfeifer
+ * Last Modified On: Wed May  7 15:33:38 1997
+ * Language        : C
+ * Update Count    : 2
+ * Status          : Unknown, Use with caution!
  * 
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
  */
 
 #ifndef lint
-static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ui/RCS/source.c,v 2.0.1.2 1995/09/15 09:53:54 pfeifer Exp $";
+static char *PRCSid = "$Id: source.c 1.7.1.5.1.4 Wed, 07 May 1997 18:04:42 +0200 pfeifer $";
 #endif
 
 #define _C_SOURCE
-/* (jp) */
 #define EXTERN_SOURCE_ITEMS
 #define EXTERN_SOURCE_PATH
 
@@ -91,13 +26,7 @@ static char *RCSid = "$Header: /usr/local/ls6/src+data/src/freeWAIS-sf-2.0/ui/RC
 
 #define DESC_SIZE 65535
 
-/*
-#if defined(BSD) || defined(BSD43)
-#include <strings.h>
-#define strchr index
-#endif
-*/
-#include "../ir/cdialect.h"
+#include "cdialect.h"
 extern int alphasort();
 
 void
