@@ -1,10 +1,17 @@
-/* WIDE AREA INFORMATION SERVER SOFTWARE:
-   No guarantees or restrictions.  See the readme file for the full standard
-   disclaimer.
+/*                               -*- Mode: C -*- 
+ * $Basename: swais.c $
+ * $Revision: 1.5.1.6.1.3 $
+ * Author          : jcurran@nnsc.nsf.net
+ * Last Modified By: Ulrich Pfeifer
+ * Last Modified On: Wed May  7 15:44:12 1997
+ * Language        : C
+ * Update Count    : 2
+ * Status          : Unknown, Use with caution!
+ * 
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
  */
 
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
-
 /* This is a simple screen user interface for making WAIS queries
  * It is the strange offspring of waisq and curses..
  *
@@ -60,7 +67,7 @@
  *
  */
 
-#include "../ir/cdialect.h"
+#include "cdialect.h"
 #include <curses.h>
 #include <signal.h>
 #include <setjmp.h>
@@ -89,7 +96,7 @@
 #define	WAIS_SERVICE	"z39_50"
 
 #define WAISSCREEN_NAME     "SWAIS"
-#define WAISSCREEN_VERSION  "$Revision: 2.0.1.3 $"
+#define WAISSCREEN_VERSION  "$Revision: 1.5.1.6.1.3 $"
 #define WAISSCREEN_AUTHOR   "John Curran (jcurran@nnsc.nsf.net)"
 
 #ifndef COMMON_SOURCE_DIR
