@@ -1,106 +1,19 @@
-/* WIDE AREA INFORMATION SERVER SOFTWARE:
-   No guarantees or restrictions.  See the readme file for the full standard
-   disclaimer.
+/*                               -*- Mode: C -*- 
+ * $Basename: waissearch.c $
+ * $Revision: 1.7.1.7.1.3 $
+ * Author          : Brewster@think.com
+ * Created On      : 92/02/16  12:13:36
+ * Last Modified By: Ulrich Pfeifer
+ * Last Modified On: Mon May  5 10:02:21 1997
+ * Language        : C
+ * Update Count    : 1
+ * Status          : Unknown, Use with caution!
+ * 
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
+ */
 
-   Brewster@think.com
-*/
-
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
-
-
-/* This is a simple shell user interface for generating wprot packets.
- * -brewster 7/90
- *
- * $Log: waissearch.c,v $
- * Revision 1.2  1996/08/14 23:51:05  julia
- * FIxed memory leak
- *
- * Revision 1.1.1.1  1996/06/04 20:37:59  julia
- * autoconf baseline
- *
- * Revision 1.1.1.1  1996/04/30 18:22:43  dmitriy
- * Version 2.1 -- autoconf baseline
- *
- * Revision 1.1.1.1  1996/04/23  14:02:50  dmitriy
- * Version 2.0
- *
- * Revision 2.0.1.2  1995/09/15 09:55:57  pfeifer
- * patch7: Fixed CNIDR copyright line.
- *
- * Revision 2.0.1.1  1995/09/11  13:01:29  pfeifer
- * patch4: Changed TELL_USER to call getuser_name().
- *
- * Revision 2.0  1995/09/08  08:05:48  pfeifer
- * Metaconfig baseline
- *
- * Revision 1.9  1995/05/03  12:24:07  pfeifer
- * getenv("USER") fix
- *
- * Revision 1.8  1994/10/06  13:28:06  pfeifer
- * Patch from Mariusz Niewczas
- *
- * Revision 1.7  1994/09/27  17:27:30  pfeifer
- * Steve Hsieh: 100000 -> BUFSZ
- *
- * Revision 1.6  1994/09/07  13:31:13  pfeifer
- * ctype is now included from cdialect.h after inclusion of string.h.
- * ds, inclusion
- * of string.h after that caused probems
- *
- * Revision 1.5  1994/08/08  07:33:09  pfeifer
- * Moved wais_log_file_name and waislogfile to cutil.[ch]
- *
- * Revision 1.3  1994/04/06  23:55:24  pfeifer
- * 08, autoconf
- *
- * Revision 1.2  1994/03/11  09:13:19  pfeifer
- * some fixes ?
- *
- * Revision 1.3  93/07/02  19:26:46  warnock
- * fix call to getdomainname from mike@tab00.larc.nasa.gov
- * 
- * Revision 1.2  93/07/01  19:22:15  warnock
- * gethostname -> mygethostname
- * 
- * Revision 1.1  93/06/23  20:02:19  warnock
- * Initial revision
- * 
- * Revision 1.1  1993/02/16  15:09:27  freewais
- * Initial revision
- *
- * Revision 1.34  92/06/03  17:29:49  jonathan
- * Fixed so it exits on NULL input.
- * 
- * Revision 1.33  92/04/29  13:21:12  jonathan
- * Updated for release.
- * 
- * Revision 1.32  92/04/09  14:19:53  morris
- * now, specifying a port on the command line does a remote search on the
- * local machine at the specified port.  the previous behavior was to do a
- * local search, even when you specify a port.
- * 
- * Revision 1.31  92/03/17  14:39:28  jonathan
- * modified to work with new ui scheme.
- * 
- * Revision 1.30  92/03/06  14:50:34  jonathan
- * Correctly handle init_connection <= 0.
- * 
- * Revision 1.29  92/03/06  12:34:57  jonathan
- * Use result of init_connection to set message length.
- * 
- * Revision 1.28  92/02/29  20:04:32  jonathan
- * Fixed spelling of opening.
- * 
- * Revision 1.27  92/02/21  11:47:48  jonathan
- * fixed code to re-init properly (instead of using connect_to_server).
- * 
- * Revision 1.26  92/02/20  16:13:15  jonathan
- * Added -m for max results.
- * 
- * Revision 1.25  92/02/16  12:13:36  jonathan
- * Added domainname to init message.
- * 
- *
+/*
  * Important functions:
  *   display_search_response
  *   main
@@ -116,7 +29,7 @@
  */
 
 #ifndef lint
-static char *RCSid = "$Header: /usr/local/cvs/wais/freeWAIS-sf-2.1/ui/waissearch.c,v 1.2 1996/08/14 23:51:05 julia Exp $";
+static char *PRCSid = "$Id: waissearch.c 1.7.1.7.1.3 Mon, 05 May 1997 11:54:27 +0200 pfeifer $";
 #endif
 
 #include <ui.h>
@@ -276,7 +189,7 @@ char *argv[];
 
   database[0] = '\0';  /* null it out */
   service[0] = '\0';
- 
+
   if(NULL == (next_argument = next_arg(&argc, &argv))){
     printf("No arguments specified\n");
     exit(0);
@@ -656,8 +569,7 @@ char *argv[];
 	      (query_info->DocHeaders[document_number - 1]->DocumentLength == 0) ||
 	      (count * CHARS_PER_PAGE <
 	      query_info->DocHeaders[document_number - 1]->DocumentLength);
-	      count++)
-	  {
+	      count++){
 	    char *type;
 	    if(query_info->DocHeaders[document_number - 1]->Types == NULL)
 	      type = s_strdup("TEXT");
@@ -730,8 +642,8 @@ char *argv[];
 	      showDiags(((WAISSearchResponse *)retrieval_response->DatabaseDiagnosticRecords)->Diagnostics);
 	      break;
 	    }
-	  s_free(type);
-	  }  /*end of for*/
+            s_free(type);
+	  }
 	  freeWAISSearchResponse( retrieval_response->DatabaseDiagnosticRecords); 
 	  freeSearchResponseAPDU( retrieval_response);
 	}
