@@ -1,4 +1,18 @@
-/* Borrowed by Jonny Goldman. */
+/*                               -*- Mode: C -*- 
+ * $Basename: myAsciiSink.c $
+ * $Revision: 1.9.1.4 $
+ * Author          : XConsortium, borrowed by Jonny Goldman.
+ * Created On      : Mon May  5 09:45:53 1997
+ * Last Modified By: Ulrich Pfeifer
+ * Last Modified On: Wed May  7 16:23:40 1997
+ * Language        : C
+ * Update Count    : 2
+ * Status          : Unknown, Use with caution!
+ * 
+ * (C) Copyright 1997, Universitt Dortmund, all rights reserved.
+ * (C) Copyright CNIDR (see ../doc/CNIDR/COPYRIGHT)
+ */
+
 /* $XConsortium: AsciiSink.c,v 1.57 91/07/21 20:35:00 converse Exp $ */
 
 /***********************************************************
@@ -25,50 +39,7 @@ SOFTWARE.
 
 ******************************************************************/
 
-/* Copyright (c) CNIDR (see ../doc/CNIDR/COPYRIGHT) */
-
-/*
- * $Log: myAsciiSink.c,v $
- * Revision 2.0.1.1  1995/09/15 09:56:43  pfeifer
- * patch7: Fixed CNIDR copyright line.
- *
- * Revision 2.0  1995/09/08  08:06:43  pfeifer
- * Metaconfig baseline
- *
- * Revision 1.9  1995/02/10  10:33:58  pfeifer
- * Release 1.1.2
- *
- * Revision 1.8  1994/10/31  15:05:12  pfeifer
- * runns under X11R6
- *
- * Revision 1.7  1994/10/21  13:01:17  pfeifer
- * Moved the Log to the top
- *
- * Revision 1.6  1994/10/21  12:50:28  pfeifer
- * Now compiles under X11R6 - query font is invisible :-(
- *
- * Revision 1.5  1994/09/08  16:43:50  pfeifer
- * Added include cdialect.h to enshur, that string.h is included before ctype.h
- *
- * Revision 1.4  1994/08/05  07:25:00  pfeifer
- * Release beta 04
- *
- * Revision 1.3  1994/03/23  19:09:33  pfeifer
- * *** empty log message ***
- *
- * Revision 1.2  93/07/02  18:33:30  warnock
- * included ctype.h
- * 
- * Revision 1.1  1993/02/16  15:10:18  freewais
- * Initial revision
- *
- * Revision 1.2  92/06/22  10:41:17  jonathan
- * Borrowed from Xaw.  Modified to use an alternate font for keyword
- * highlighting.
- * 
- */
-
-#include "../ir/cdialect.h"
+#include "cdialect.h"
 #include <stdio.h>
 #include <ctype.h>
 
