@@ -1,6 +1,6 @@
 /*                               -*- Mode: C -*- 
  * $Basename: myAsciiSrc.c $
- * $Revision: 1.12.1.4 $
+ * $Revision: 1.12.1.5 $
  * Author          : XConsortium, borrowed by Jonny Goldman.
  * Created On      : 91/07/25 18:09:27
  * Last Modified By: Ulrich Pfeifer
@@ -117,9 +117,6 @@ static Boolean SetValues(), WriteToFile();
 
 
 #ifdef HAS_SYS_ERRLIST
-#ifdef EXTERN_SYS_ERRLIST
-extern char *sys_errlist[];
-#endif
 extern int      errno;
 extern int      sys_nerr;
 #endif
